@@ -9,7 +9,7 @@ use AnyEvent::Handle;
 
 use Carp;
 
-our $VERSION = '0.11';
+our $VERSION = '0.9';
 
 sub FREEZE ()	{ 0 }
 sub THAW ()	{ 1 }
@@ -148,8 +148,7 @@ sub new
 				$serializer, $compress);
 		    }
 
-		    # FreezeThaw returns in list context...
-		    if (my($ref) = eval {
+		    if (my $ref = eval {
 			$serializer->[AnyEvent::POE_Reference::THAW]->(
 			    substr($buf, length($1) + 1)) })
 		    {
